@@ -12,7 +12,7 @@
  * $tz->getZone('America/New_York')->toVtimezone()->exportVcalendar();
  * </code>
  *
- * Copyright 2011-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -180,19 +180,28 @@ class Horde_Timezone
             stream_copy_to_stream($response->getStream(), fopen($this->_tmpfile, 'w'));
             return;
         }
-        try {
-            if ($url['scheme'] == 'ftp') {
+        if ($url['scheme'] == 'ftp') {
+            try {
                 $vfs = new Horde_Vfs_Ftp(array('hostspec' => $url['host'],
                                                'username' => 'anonymous',
-                                               'password' => 'anonymous'));
-            } else {
-                $vfs = new Horde_Vfs_File();
+                                               'password' => 'anonymous',
+                                               'pasv' => true));
+                $this->_tmpfile = $vfs->readFile(dirname($url['path']),
+                                                 basename($url['path']));
+            } catch (Horde_Vfs_Exception $e) {
+                throw new Horde_Timezone_Exception($e);
+            }
+        } else {
+            $this->_tmpfile = $this->_params['location'];
+            if (!is_readable($this->_tmpfile)) {
+                $e = new Horde_Timezone_Exception(sprintf('Unable to open file %s.', $this->_params['location']));
+                if (isset($php_errormsg)) {
+                    $e->details = $php_errormsg;
+                }
+                throw $e;
             }
-            $this->_tmpfile = $vfs->readFile(dirname($url['path']),
-                                             basename($url['path']));
-        } catch (Horde_Vfs_Exception $e) {
-            throw new Horde_Timezone_Exception($e);
         }
+
     }
 
     /**
